"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("../core");
function createBrowserLogger() {
    var logger = new core_1.LoggerImpl({
        out: function (i) { output(console.log, i); },
        err: function (i) { output(console.error, i); },
    });
    return logger;
}
exports.default = createBrowserLogger;
function output(print, i) {
    var message = i.message;
    if (i.colorize) {
        message = "[%c" + i.level + "%c] " + message;
    }
    else {
        message = "[" + i.level + "] " + message;
    }
    if (i.timestamp) {
        message = "[" + i.timestamp + "]" + message;
    }
    if (i.colorize) {
        print.apply(void 0, [message, color(i.level), color("silent")].concat(i.meta));
        if (i.listener) {
            i.listener(Reflect.apply(sprintf, null, [message, "(", ")"].concat(i.meta)));
        }
    }
    else {
        print.apply(void 0, [message].concat(i.meta));
        if (i.listener) {
            i.listener(Reflect.apply(sprintf, null, [message].concat(i.meta)));
        }
    }
}
function color(level) {
    switch (level) {
        case "error": return "color: red;";
        case "warn": return "color: yellow;";
        case "info": return "color: green;";
        case "verbose": return "color: cyan;";
        case "debug": return "color: blue;";
        case "silly": return "color: magenta;";
    }
    return "color: initial;";
}
// Credit: https://stackoverflow.com/a/4795914/1123955
function sprintf() {
    var args = arguments;
    var text = args[0];
    var i = 1;
    return text.replace(/%((%)|s|d|j|o|O)/g, function (m) {
        // m is the matched format, e.g. %s, %d, %j, %o, %O
        var val = null;
        if (m[2]) {
            val = m[2];
        }
        else {
            val = args[i];
            // A switch statement so that the formatter can be extended. Default is %s
            switch (m) {
                case "%d":
                    val = parseFloat(val);
                    if (isNaN(val)) {
                        val = 0;
                    }
                    break;
                case "%j":
                case "%o":
                case "%O":
                    val = JSON.stringify(val);
                    break;
            }
            i++;
        }
        return val;
    });
}
