
declare module 'hbblog' {
   interface IStandardizedLogger {
  error(message: string, ...meta: any[]): void;
  warn(message: string, ...meta: any[]): void;
  info(message: string, ...meta: any[]): void;
  verbose(message: string, ...meta: any[]): void;
  debug(message: string, ...meta: any[]): void;
  silly(message: string, ...meta: any[]): void;
}

 const enum LogLevel {
  silent = -1,
  error,
  warn,
  info,
  verbose,
  debug,
  silly,
  all,
}

 type LogLevelLiteral = keyof typeof LogLevel;

 interface ILogFormatterInfo {
  timestamp: Date;
  level: LogLevelLiteral;
  message: string;
  meta?: any[];
}

 type TimestampFormatter = (date: Date) => string;

 type LogListener = (message: string) => void;

 interface ILogger extends IStandardizedLogger {
  defer: IStandardizedLogger;

  level(lv: LogLevelLiteral): this;
  colorize(v: boolean): this;
  timestamp(v: TimestampFormatter | null): this;
  errorLevels(levels: LogLevelLiteral[]): this;
  listen(hd: LogListener): this;
}


  function createNodeLogger(): ILogger;
  function createBrowserLogger(): ILogger;
}

declare module 'hbblog/node' {
  import { createNodeLogger } from "hbblog";
  export default createNodeLogger;
}

declare module 'hbblog/browser' {
  import { createBrowserLogger } from "hbblog";
  export default createBrowserLogger;
}
